@@ -1,11 +1,12 @@
 import os
 from pathlib import Path
 from string import Template
-from typing import Type, List, TYPE_CHECKING
+from typing import Type, List, TYPE_CHECKING, Optional
+from uuid import uuid4
 
 import ipywidgets.widgets as widgets
 import ujson
-from IPython.core.display import Javascript
+from IPython.core.display import Javascript, display
 from ipycallback import SlowTunnelWidget
 
 if TYPE_CHECKING:
@@ -18,7 +19,7 @@ import labext.modules as M
 
 
 class DataTable(WidgetWrapper):
-    def __init__(self, df: 'DataFrame', table_class: str='display', **kwargs):
+    def __init__(self, df: 'DataFrame', table_class: str='display', table_id: Optional[str]=None, **kwargs):
         """Show the
 
         Parameters
@@ -27,15 +28,19 @@ class DataTable(WidgetWrapper):
             the data frame that we want to display
         table_class: str
             html classes for formatting the table's style: https://datatables.net/manual/styling/classes
+        table_id: Optional[str]
+            id of the table, manually giving the table an id helps reducing number of instances in the client
+            as we store this data table in the client side to reduce the
         kwargs
             see the [examples](https://datatables.net/examples/index) and the [options](https://datatables.net/manual/options)
             the options will be passed directly to the client
         """
         self.df = df
         self.table_class = table_class
+        self.table_id = table_id or str(uuid4())
         self.options = kwargs
 
-        self.tunnel = SlowTunnelWidget()
+        self.tunnel = SlowTunnelWidget(tunnel_id=self.table_id)
         self.tunnel.on_receive(self.on_receive_updates)
         self.el = widgets.HTML(value="")
         self.el_class_id = f"DataTable_{self.el.model_id}"
@@ -58,24 +63,21 @@ class DataTable(WidgetWrapper):
                         window.$container.DataTable = new Map();
                     }
                     
+                    let tunnel = window.IPyCallback.get("$tunnelId");
                     let model = new LabExtDataTable(
-                        jquery, el, 
-                        window.IPyCallback.get("$tunnelId"),
-                        $columns,
-                        "$table_class",
-                        $options
+                        jquery, el, tunnel,
+                        $columns, "$table_class", $options
                     );
                     model.render();
-                    window.$container.DataTable.set("$modelId", model);
-
+                    window.$container.DataTable.set("$tableId", model);
                     return true;
                 }, 100);
             });
         """.strip()).substitute(JQueryId=M.JQuery.id(), CallUntilTrue=M.LabExt.call_until_true,
                                 container=M.LabExt.container,
                                 containerClassId=self.el_class_id,
-                                modelId=self.el.model_id,
-                                tunnelId=self.tunnel.model_id,
+                                tableId=self.table_id,
+                                tunnelId=self.tunnel.tunnel_id,
                                 columns=ujson.dumps(self.df.columns.tolist()),
                                 table_class=self.table_class,
                                 options=ujson.dumps(self.options))
@@ -93,6 +95,17 @@ class DataTable(WidgetWrapper):
     def get_auxiliary_components(self, *args) -> list:
         return self.el_auxiliaries
 
+    def destroy(self):
+        jscode = Template("""
+                window.IPyCallback.delete("$tunnelId");
+                window.$container.DataTable.delete("$tableId");
+                """).substitute(
+            tableId=self.table_id,
+            tunnelId=self.tunnel.tunnel_id,
+            container=M.LabExt.container,
+        )
+        display(Javascript(jscode))
+
     def on_receive_updates(self, version: int, msg: str):
         msg = ujson.loads(msg)
         if msg['type'] == 'query':
